package basic

import (
	"github.com/gin-gonic/gin"
	"go-admin/app/admin/middleware"
	"go-admin/app/admin/models"
	orm "go-admin/common/global"
	"go-admin/logger"
	"go-admin/tools"
	"go-admin/tools/app"
)

type CreateCategoryRequest struct {
	Name     string `json:"name" validate:"required"` //名称
	ParentId uint32 `json:"parent_id"`                //父分类id
}

// CreateCategory 创建分类
// @Summary 创建分类
// @Tags 商品分类
// @Produce json
// @Accept json
// @Param request body CreateCategoryRequest true "商品分类创建模型"
// @Success 200 {object} app.Response
// @Router /api/v1/category/create [post]
func CreateCategory(c *gin.Context) {
	var req = new(CreateCategoryRequest)

	if err := c.ShouldBindJSON(req); err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	err := tools.Validate(req)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	category := models.Category{
		Name:                  req.Name,
		Display:               1,
		Pid:                   req.ParentId,
		CooperativeBusinessId: middleware.GetCooperativeBusinessId(c),
	}

	err = orm.Eloquent.Model(category).Create(category).Error
	if err != nil {
		logger.Error("创建分类失败", logger.Field("category", category), logger.Field("err", err))
		app.Error(c, 500, err, "创建分类失败")
		return
	}

	app.OK(c, nil, "ok")
}
